@@ -43,6 +43,21 @@ my %tree =
 		}
 	, B => 'scalar'
 	, C => [qw(element_1 element_2)]
+	, HASH =>
+		{
+		a => 'a',
+		1 => 1,
+		'1a' => 1,
+		2 => 2,
+		9 => 9,
+		10 => 10,
+		11 => 11,
+		19 => 19,
+		20 => 20,
+		'2b' => '2b',
+		'2b0' => '2b0',
+		'20b' => '20b',
+		}
 	) ;
 
 my $hi = '25' ;
@@ -104,7 +119,7 @@ my $tree_dumper = new Data::TreeDumper::OO ;
 #~ $tree_dumper->UseAscii(0) ;
 #~ $tree_dumper->SetMaxDepth(2) ;
  
-print $tree_dumper->Dump(\%tree, "Data:TreeDumper dump example:",  DISPLAY_ROOT_ADDRESS => 1, DISPLAY_PERL_SIZE => 1, NO_WRAP => 1) ;
+print $tree_dumper->Dump(\%tree, "Data:TreeDumper dump example:",  DISPLAY_ROOT_ADDRESS => 1, DISPLAY_PERL_SIZE => 1) ;
 
 #~ print $tree_dumper->Dump(\%tree, "Data:TreeDumper dump example:", INDENTATION => '  ', FILTER => \&Data::TreeDumper::HashKeysSorter) ;
 
